import { LitElement } from 'lit';
declare const UUIRangeSliderElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").FormControlMixinInterface) & typeof LitElement;
/**
 * @element uui-range-slider
 * @description - Range slider with two handles. Use uui-slider for a single handle.
 * @fires UUIRangeSliderEvent#input on input
 * @fires UUIRangeSliderEvent#change on change
 */
export declare class UUIRangeSliderElement extends UUIRangeSliderElement_base {
    #private;
    static readonly formAssociated = true;
    /**
     * Label to be used for aria-label and eventually as visual label. Adds "low-end value" and "high-end value" endings for the two values.
     * @type {string}
     * @attr
     */
    label: String;
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    /**
     * Sets the minimum allowed value.
     * @type {number}
     * @attr min
     * @default 0
     */
    get min(): number;
    set min(newVal: number);
    _min: number;
    /**
     * Sets the maximum allowed value.
     * @type {number}
     * @attr max
     * @default 100
     */
    get max(): number;
    set max(newVal: number);
    _max: number;
    /**
     * Hides the numbers representing the value of each steps. Dots will still be visible
     * @type {boolean}
     * @attr 'hide-step-values'
     * @default false
     */
    hideStepValues: boolean;
    /**
     * This reflects the behavior of a native input step attribute.
     * @type {number}
     * @attr
     * @default 1
     */
    get step(): number;
    set step(newVal: number);
    _step: number;
    /**
     * Minimum value gap between the the two picked values. Cannot be lower than the step value and cannot be higher than the maximum gap
     * @type {number}
     * @attr min-gap
     * @default undefined
     */
    get minGap(): number | undefined;
    set minGap(newVal: number | undefined);
    _minGap?: number;
    /**
     * Maximum value gap between the the two picked values. Cannot be lower than the minimum gap.
     * @type {number}
     * @attr max-gap
     * @default undefined
     */
    get maxGap(): number | undefined;
    set maxGap(newVal: number | undefined);
    _maxGap?: number;
    /**
     * This is a value property of the uui-range-slider. Split the two values with comma, for example 10,50 sets the values to 10 and 50.
     * @type {string}
     * @attr
     * @default 0,0
     */
    get value(): FormDataEntryValue | FormData;
    set value(newVal: FormDataEntryValue | FormData);
    private _currentFocus?;
    private _movement;
    private startPoint;
    private _lowInputValue;
    private _highInputValue;
    private _trackWidth;
    _lowValuePercentStart: number;
    _highValuePercentEnd: number;
    protected setValueLow(low: number): void;
    protected setValueHigh(high: number): void;
    protected setValue(low: number, high: number, lockValueRange?: boolean): void;
    protected getFormElement(): HTMLInputElement;
    /** Elements */
    private _outerTrack;
    private _inputLow;
    private _inputHigh;
    private _innerColor;
    private _innerColorThumb;
    /** Constructor and Validator */
    constructor();
    connectedCallback(): void;
    firstUpdated(changedProperties: Map<string | number | symbol, unknown>): void;
    private _runPropertiesChecks;
    private _updateInnerColor;
    private _getClickedValue;
    /** Events */
    private _onKeypress;
    /** Touch Event */
    private _onTouchStart;
    private _onTouchMove;
    private _onTouchEnd;
    /** Mouse Event */
    private _onMouseDown;
    private _onMouseMove;
    private _onMouseUp;
    /** Drag both thumbs logics */
    private _saveStartPoints;
    private _dragBothValuesByMousePos;
    /** Input Events */
    private _onLowInput;
    private _onHighInput;
    /** Change Events */
    private _onLowChange;
    private _onHighChange;
    protected onChanged(): void;
    /** Render */
    render(): import("lit-html").TemplateResult<1>;
    private _renderThumbValues;
    private _renderSteps;
    private _renderStepValues;
    private _renderStepCircles;
    private _renderNativeInputs;
    /** Style */
    static styles: import("lit").CSSResult[];
}
declare global {
    interface HTMLElementTagNameMap {
        'uui-range-slider': UUIRangeSliderElement;
    }
}
export {};
